# Wagtail QRcode Changelog

## Uneleased

## [1.1.2] - 2023-02-13

- General tidy up around tests and docs
- Drop older versions
- Move tests and tes with postgres and mysql as well as sqlite

## [1.0.0] - 2022-09-09

- [Support Wagtail 4](https://github.com/nickmoreton/wagtail-qrcode/pull/24)

## [0.1.4] - 2022-08-17

- [Change admin form and misc. improvements](https://github.com/nickmoreton/wagtail-qrcode/pull/23)

## [0.1.3] - 2022-08-14

- [Add more options around emailing EPS](https://github.com/nickmoreton/wagtail-qrcode/pull/19)
- [Improve documentation](https://github.com/nickmoreton/wagtail-qrcode/pull/18)

## [0.1.2] - 2022-08-12

Correct version

## [0.1.1] - 2022-08-12

Allow python >=3.7

## [0.1.0] - 2022-08-11

Initial release
